#[non_exhaustive]pub enum RelayId {
Ed25519(Ed25519Identity),
Rsa(RsaIdentity),
}Expand description
A single relay identity.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Ed25519(Ed25519Identity)
An Ed25519 identity.
Every relay (currently) has one of these identities. It is the same as the encoding of the relay’s public Ed25519 identity key.
Rsa(RsaIdentity)
An RSA identity.
Every relay (currently) has one of these identities. It is computed as a SHA-1 digest of the DER encoding of the relay’s public RSA 1024-bit identity key. Because of short key length, this type of identity should not be considered secure on its own.
Implementations
Sourceimpl RelayId
impl RelayId
Sourcepub fn as_ref(&self) -> RelayIdRef<'_>
pub fn as_ref(&self) -> RelayIdRef<'_>
Return a RelayIdRef pointing to the contents of this identity.
Sourcepub fn from_type_and_bytes(
id_type: RelayIdType,
id: &[u8],
) -> Result<Self, RelayIdError>
pub fn from_type_and_bytes( id_type: RelayIdType, id: &[u8], ) -> Result<Self, RelayIdError>
Try to construct a RelayId of a provided id_type from a byte-slice.
Return RelayIdError::BadLength if the slice is not the correct length for the key.
Sourcepub fn id_type(&self) -> RelayIdType
pub fn id_type(&self) -> RelayIdType
Return the type of this relay identity.