#[non_exhaustive]pub enum RelayIdError {
UnrecognizedIdType,
BadBase64,
BadHex,
BadLength,
}Expand description
An error returned while trying to parse a RelayId.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnrecognizedIdType
We didn’t recognize the type of a relay identity.
This can happen when a type that we have never heard of is specified, or when a type
BadBase64
We encountered base64 data that we couldn’t parse.
BadHex
We encountered hex data that we couldn’t parse.
BadLength
We got a key that was the wrong length.