#[non_exhaustive]pub enum RelayIdRef<'a> {
Ed25519(&'a Ed25519Identity),
Rsa(&'a RsaIdentity),
}Expand description
A reference to a single relay identity.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Ed25519(&'a Ed25519Identity)
An Ed25519 identity.
Every relay (currently) has one of these identities. It is the same as the encoding of the relay’s public Ed25519 identity key.
Rsa(&'a RsaIdentity)
An RSA identity.
Every relay (currently) has one of these identities. It is computed as a SHA-1 digest of the DER encoding of the relay’s public RSA 1024-bit identity key. Because of short key length, this type of identity should not be considered secure on its own.
Implementations
Sourceimpl<'a> RelayIdRef<'a>
impl<'a> RelayIdRef<'a>
Sourcepub fn id_type(&self) -> RelayIdType
pub fn id_type(&self) -> RelayIdType
Return the type of this relay identity.
Sourcepub fn as_bytes(&self) -> &'a [u8] ⓘ
pub fn as_bytes(&self) -> &'a [u8] ⓘ
Return a byte-slice corresponding to the contents of this identity.
Sourcepub(crate) fn unwrap_ed25519(self) -> &'a Ed25519Identity
pub(crate) fn unwrap_ed25519(self) -> &'a Ed25519Identity
Extract the Ed25519Identity from a RelayIdRef that is known to hold one.
Panics
Panics if this is not an $vname identity.
Sourcepub(crate) fn unwrap_rsa(self) -> &'a RsaIdentity
pub(crate) fn unwrap_rsa(self) -> &'a RsaIdentity
Extract the RsaIdentity from a RelayIdRef that is known to hold one.
Panics
Panics if this is not an $vname identity.