#[non_exhaustive]pub enum TransportIdError {
NoSupport,
BadId(String),
}Expand description
An error related to parsing a TransportId.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoSupport
Arti was compiled without client-side pluggable transport support, and we tried to use a pluggable transport.
BadId(String)
Tried to parse a pluggable transport whose name was not well-formed.