RelayIdsBuilder

Struct RelayIdsBuilder 

pub struct RelayIdsBuilder { /* private fields */ }
Builder for RelayIds.

Implementations

Source

impl RelayIdsBuilder

pub fn ed_identity(&mut self, value: Ed25519Identity) -> &mut Self

Copy of the ed25519 id from the underlying ChanTarget.

pub fn rsa_identity(&mut self, value: RsaIdentity) -> &mut Self

Copy of the rsa id from the underlying ChanTarget.

pub fn build(&self) -> Result<RelayIds, RelayIdsBuilderError>

Builds a new RelayIds.

Errors

If a required field has not been initialized.

Source

impl RelayIdsBuilder

pub fn from_relay_ids<T: HasRelayIds + ?Sized>(ids: &T) -> Self

Construct a new RelayIdsBuilder object from an object implementing HasRelayIds.

Note that it is possible to construct an empty RelayIds object if the input does not contain any recognized identity type.